@@ -78,8 +78,8 @@ def _symbol_to_classname(symbol: str) -> str:
 
 class MultiLabel:
     """
-    Helper class for defining multi-value label for tokens. Useful when a symbol has more roles.
-    A label of this type has equivalence with each of its values.
+    Helper class for defining multi-value label for tokens. Useful when a symbol
+    has more roles. A label of this type has equivalence with each of its values.
 
     Example:
         label = MultiLabel('function', 'operator')
@@ -202,11 +202,9 @@ class Token(MutableSequence[TK]):
             return '%r %s' % (self.symbol, str(self.label))
 
     def __repr__(self) -> str:
-        symbol, value = self.symbol, self.value
-        if value != symbol:
-            return '%s(value=%r)' % (self.__class__.__name__, value)
-        else:
-            return '%s()' % self.__class__.__name__
+        if self.value == self.symbol:
+            return '%s(%r)' % (self.__class__.__name__, self.parser)
+        return '%s(%r, %r)' % (self.__class__.__name__, self.parser, self.value)
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Token):
@@ -244,7 +242,7 @@ class Token(MutableSequence[TK]):
         elif symbol == '(decimal)':
             return str(self.value)
         elif symbol in SPECIAL_SYMBOLS:
-            return repr(self.value)
+            return repr(self.value).replace(r'\\', '\\')
         else:
             length = len(self)
             if not length:
@@ -471,6 +469,9 @@ class Parser(Generic[TK_co], metaclass=ParserMeta):
         self._start_token = self.symbol_table['(start)'](self)
         self.token = self.next_token = self._start_token
 
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}()'
+
     def __eq__(self, other: object) -> bool:
         return isinstance(other, Parser) and \
             self.token_base_class is other.token_base_class and \
@@ -686,10 +687,14 @@ class Parser(Generic[TK_co], metaclass=ParserMeta):
                 if isinstance(label, tuple):
                     label = kwargs['label'] = MultiLabel(*label)
 
-                token_class_name = "_{}{}".format(
-                    _symbol_to_classname(symbol),
-                    str(label).title().replace(' ', '')
-                )
+                if 'class_name' in kwargs:
+                    token_class_name = kwargs.pop('class_name')
+                else:
+                    token_class_name = "_{}{}".format(
+                        _symbol_to_classname(symbol),
+                        str(label).title().replace(' ', '')
+                    )
+
                 token_class_bases = kwargs.get('bases', (cls.token_base_class,))
                 kwargs.update({
                     '__module__': cls.__module__,
@@ -822,8 +827,6 @@ class Parser(Generic[TK_co], metaclass=ParserMeta):
 
         cls.tokenizer = cls.create_tokenizer(cls.symbol_table)
 
-    build_tokenizer = build  # For backward compatibility
-
     @classmethod
     def create_tokenizer(cls, symbol_table: MutableMapping[str, Type[TK_co]]) -> Pattern[str]:
         """
